@@ -2,9 +2,6 @@
  * config file for xbuffy.  
  */
 
-/* Enable debugging info */
-#undef DEBUG
-
 @TOP@
 
 /* if you want Xbuffy to try to use Content-Length: headers uncomment the
@@ -35,3 +32,10 @@
 
 /* program to use for shell commands */
 #define EXECSHELL "/bin/sh"
+
+/* Enable SSL? */
+#undef HAVE_SSL
+
+/* Enable debugging info */
+#undef DEBUG
+
