@@ -31,6 +31,10 @@ static GtkWidget *MailboxCList;
 static GtkWidget *TypeOptionMenu;
 static GtkWidget *ServerEntry;
 static GtkWidget *ServerLabel;
+#ifdef HAVE_SSL
+static GtkWidget *SSLLabel;
+static GtkWidget *SSLCheckbox;
+#endif
 static GtkWidget *PortEntry;
 static GtkWidget *PortLabel;
 static GtkWidget *LoginEntry;
@@ -88,6 +92,11 @@ static void configure_select_mailbox (GtkWidget *clist, gint row, gint column,
     gtk_entry_set_text (GTK_ENTRY (ServerEntry), 
 	box->server ? box->server : 
 	(box->type == GB_IMAP) ? "imap" : DefaultNewserver);
+#ifdef HAVE_SSL
+    gtk_widget_show (SSLLabel);
+    gtk_widget_show (SSLCheckbox);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (SSLCheckbox), box->ssl_mode ? TRUE : FALSE);
+#endif
     gtk_widget_show (PortLabel);
     gtk_widget_show (PortEntry);
     if (box->port)
@@ -97,8 +106,13 @@ static void configure_select_mailbox (GtkWidget *clist, gint row, gint column,
       gtk_entry_set_text (GTK_ENTRY (PortEntry), buf);
     }
     else
+#ifdef HAVE_SSL
+      gtk_entry_set_text (GTK_ENTRY (PortEntry), 
+	  (box->type == GB_IMAP) ? (box->ssl_mode ? "993" : "143") : "119");
+#else
       gtk_entry_set_text (GTK_ENTRY (PortEntry), 
 	  (box->type == GB_IMAP) ? "143" : "119");
+#endif
     gtk_widget_show (LoginLabel);
     gtk_widget_show (LoginEntry);
     gtk_entry_set_text (GTK_ENTRY (LoginEntry), 
@@ -108,6 +122,8 @@ static void configure_select_mailbox (GtkWidget *clist, gint row, gint column,
   {
     gtk_widget_hide (ServerLabel);
     gtk_widget_hide (ServerEntry);
+    gtk_widget_hide (SSLLabel);
+    gtk_widget_hide (SSLCheckbox);
     gtk_widget_hide (PortLabel);
     gtk_widget_hide (PortEntry);
     gtk_widget_hide (LoginLabel);
@@ -157,6 +173,10 @@ static void configure_set_box (BOX_INFO *box)
     box->server = strdup (gtk_entry_get_text (GTK_ENTRY (ServerEntry)));
     if (box->type == GB_NNTP)
       box->newsrc = strdup (gtk_entry_get_text (GTK_ENTRY (NewsrcEntry)));
+#ifdef HAVE_SSL
+    else
+      box->ssl_mode = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (SSLCheckbox)) == TRUE;
+#endif
     box->port = atoi (gtk_entry_get_text (GTK_ENTRY (PortEntry)));
   }
 }
@@ -187,6 +207,11 @@ static void configure_set_type (GtkWidget *widget, gpointer data)
     gtk_widget_show (ServerEntry);
     gtk_entry_set_text (GTK_ENTRY (ServerEntry), 
 	(type == GB_IMAP) ? "imap" : "news");
+#ifdef HAVE_SSL
+    gtk_widget_show (SSLLabel);
+    gtk_widget_show (SSLCheckbox);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (SSLCheckbox), FALSE);
+#endif
     gtk_widget_show (PortLabel);
     gtk_widget_show (PortEntry);
     gtk_entry_set_text (GTK_ENTRY (PortEntry), 
@@ -199,6 +224,8 @@ static void configure_set_type (GtkWidget *widget, gpointer data)
   {
     gtk_widget_hide (ServerLabel);
     gtk_widget_hide (ServerEntry);
+    gtk_widget_hide (SSLLabel);
+    gtk_widget_hide (SSLCheckbox);
     gtk_widget_hide (PortLabel);
     gtk_widget_hide (PortEntry);
     gtk_widget_hide (LoginLabel);
@@ -224,6 +251,10 @@ static void configure_set_type (GtkWidget *widget, gpointer data)
 	  gtk_entry_set_text (GTK_ENTRY (LoginEntry), box->login);
 	if (box->server)
 	  gtk_entry_set_text (GTK_ENTRY (ServerEntry), box->server);
+#ifdef HAVE_SSL
+	if (box->ssl_mode)
+	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (SSLCheckbox), TRUE);
+#endif
 	if (box->port)
 	{
 	  char buf[SHORT_STRING];
@@ -477,6 +508,7 @@ void gbuffy_configure_dialog ()
   char *titles[] = {"Mailboxes", NULL};
   BOX_INFO *box;
   int x;
+  int row;
   static OptionMenuItem *types = NULL;
   char buf[STRING];
 
@@ -543,7 +575,11 @@ void gbuffy_configure_dialog ()
     gtk_widget_show (hbox2);
     gtk_widget_show (vbox);
 
+#ifdef HAVE_SSL
+    table = gtk_table_new (3, 9, FALSE);
+#else
     table = gtk_table_new (3, 8, FALSE);
+#endif
     gtk_table_set_row_spacings (GTK_TABLE (table), 5);
     gtk_table_set_col_spacings (GTK_TABLE (table), 5);
     gtk_container_border_width (GTK_CONTAINER (table), 10);
@@ -559,69 +595,89 @@ void gbuffy_configure_dialog ()
 	types[x].data = GINT_TO_POINTER (x);
       }
     }
+    row = 1;
+
     label = gtk_label_new ("Type:");
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, 
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 0);
     gtk_widget_show (label);
     TypeOptionMenu = create_option_menu (types, GB_MAX);
-    gtk_table_attach (GTK_TABLE (table), TypeOptionMenu, 1, 2, 0, 1, 
+    gtk_table_attach (GTK_TABLE (table), TypeOptionMenu, 1, 2, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 0);
     gtk_widget_show (TypeOptionMenu);
+    row++;
 
     label = gtk_label_new ("Title:");
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, 
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 0);
     gtk_widget_show (label);
     TitleEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), TitleEntry, 1, 3, 1, 2, 
+    gtk_table_attach (GTK_TABLE (table), TitleEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 0);
     gtk_widget_show (TitleEntry);
+    row++;
 
     ServerLabel = gtk_label_new ("Server:");
-    gtk_table_attach (GTK_TABLE (table), ServerLabel, 0, 1, 2, 3, 
+    gtk_table_attach (GTK_TABLE (table), ServerLabel, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     ServerEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), ServerEntry, 1, 3, 2, 3, 
+    gtk_table_attach (GTK_TABLE (table), ServerEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    row++;
+
+#ifdef HAVE_SSL
+    SSLLabel = gtk_label_new ("SSL:");
+    gtk_table_attach (GTK_TABLE (table), SSLLabel, 0, 1, row - 1, row,
+	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    SSLCheckbox = gtk_check_button_new();
+    gtk_table_attach (GTK_TABLE (table), SSLCheckbox, 1, 3, row - 1, row,
+	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    row++;
+#endif
 
     PortLabel = gtk_label_new ("Port:");
-    gtk_table_attach (GTK_TABLE (table), PortLabel, 0, 1, 3, 4, 
+    gtk_table_attach (GTK_TABLE (table), PortLabel, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     PortEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), PortEntry, 1, 3, 3, 4, 
+    gtk_table_attach (GTK_TABLE (table), PortEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    row++;
 
     LoginLabel = gtk_label_new ("Login:");
-    gtk_table_attach (GTK_TABLE (table), LoginLabel, 0, 1, 4, 5, 
+    gtk_table_attach (GTK_TABLE (table), LoginLabel, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     LoginEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), LoginEntry, 1, 3, 4, 5, 
+    gtk_table_attach (GTK_TABLE (table), LoginEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    row++;
 
     label = gtk_label_new ("Path:");
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6, 
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     gtk_widget_show (label);
     PathEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), PathEntry, 1, 3, 5, 6, 
+    gtk_table_attach (GTK_TABLE (table), PathEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     gtk_widget_show (PathEntry);
+    row++;
 
     NewsrcLabel = gtk_label_new ("Newsrc:");
-    gtk_table_attach (GTK_TABLE (table), NewsrcLabel, 0, 1, 6, 7, 
+    gtk_table_attach (GTK_TABLE (table), NewsrcLabel, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     NewsrcEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), NewsrcEntry, 1, 3, 6, 7, 
+    gtk_table_attach (GTK_TABLE (table), NewsrcEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
+    row++;
 
     label = gtk_label_new ("Command:");
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 7, 8, 
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     gtk_widget_show (label);
     CommandEntry = gtk_entry_new ();
-    gtk_table_attach (GTK_TABLE (table), CommandEntry, 1, 3, 7, 8, 
+    gtk_table_attach (GTK_TABLE (table), CommandEntry, 1, 3, row - 1, row, 
 	GTK_EXPAND | GTK_FILL, GTK_EXPAND, 0, 5);
     gtk_widget_show (CommandEntry);
+    row++;
 
     gtk_widget_show (table);
     gtk_widget_show (hbox);
@@ -631,6 +687,9 @@ void gbuffy_configure_dialog ()
     gtk_table_set_col_spacings (GTK_TABLE (table), 5);
     gtk_container_border_width (GTK_CONTAINER (table), 10);
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (ConfigureWindow)->vbox), table, TRUE, TRUE, 0);
+#ifndef GNOME_APPLET
+    /* We don't need to configure this here, the applet detects
+     * orientation changes automatically. */
     button = gtk_check_button_new_with_label ("Vertical");
     gtk_table_attach (GTK_TABLE (table), button, 0, 1, 0, 1, 
 	GTK_FILL, GTK_EXPAND, 0, 5);
@@ -638,6 +697,7 @@ void gbuffy_configure_dialog ()
     gtk_signal_connect(GTK_OBJECT(button), "toggled",
 	GTK_SIGNAL_FUNC(toggle_var_callback), &Vertical);
     gtk_widget_show (button);
+#endif
 
     label = gtk_label_new ("Mail Directory:");
     gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, 
