@@ -177,8 +177,9 @@ gint configure_event (GtkWidget *da, GdkEventConfigure *event, BOX_INFO *box)
 {
   GList *headers;
   int y = box->height;
-  int x;
+  int x, skip = 0;
   int face_display = FALSE;
+  int any_display = FALSE;
   GdkPixmap *black;
   GdkGC *mask_gc;
 
@@ -207,43 +208,69 @@ gint configure_event (GtkWidget *da, GdkEventConfigure *event, BOX_INFO *box)
       MESSAGE_INFO *m = (MESSAGE_INFO *)(headers->data);
 
       face_display = FALSE;
+      any_display = FALSE;
       if (m->face)
       {
-	char buf[2048];
-	GdkPixmap *face;
-
-	strfcpy (buf, m->face, sizeof (buf));
-	if (uncompface (buf) >= 0)
+	if (skip < box->skip_num) skip++;
+	else
 	{
-	  face = pixmap_from_ikon (box->pixmap, buf); 
-	  gdk_gc_set_clip_mask (mask_gc, face); 
-	  gdk_gc_set_clip_origin (mask_gc, 2, y - box->height + 3);
-	  gdk_draw_pixmap (box->pixmap, mask_gc, black, 0, 0, 2, y - box->height+3, -1, -1);
-	  /*
-	  gdk_draw_bitmap (box->pixmap, 
-	      da->style->light_gc[GTK_WIDGET_STATE (da)],
-	      face, 0, 0, 2, y - box->height + 3, -1, -1);
-	  */
-	  gdk_gc_set_clip_mask (mask_gc, NULL); 
-	  gdk_pixmap_unref (face); 
-	  face_display = TRUE;
+	  char buf[2048];
+	  GdkPixmap *face;
+
+	  strfcpy (buf, m->face, sizeof (buf));
+	  if (uncompface (buf) >= 0)
+	  {
+	    face = pixmap_from_ikon (box->pixmap, buf); 
+	    gdk_gc_set_clip_mask (mask_gc, face); 
+	    gdk_gc_set_clip_origin (mask_gc, 2, y - box->height + 3);
+	    gdk_draw_pixmap (box->pixmap, mask_gc, black, 0, 0, 2, y - box->height+3, -1, -1);
+	    /*
+	       gdk_draw_bitmap (box->pixmap, 
+	       da->style->light_gc[GTK_WIDGET_STATE (da)],
+	       face, 0, 0, 2, y - box->height + 3, -1, -1);
+	     */
+	    gdk_gc_set_clip_mask (mask_gc, NULL); 
+	    gdk_pixmap_unref (face); 
+	    face_display = TRUE;
+	  }
+	}
+      }
+      if (m->from)
+      {
+	if (skip < box->skip_num) skip++;
+	else
+	{
+	  any_display = TRUE;
+	  gdk_draw_string (box->pixmap, da->style->font, 
+	      da->style->fg_gc[GTK_WIDGET_STATE (da)], 
+	      x, y + (face_display * 3), 
+	      m->from);
+	  y += box->height;
+	}
+      }
+      if (m->subject)
+      {
+	if (skip < box->skip_num) skip++;
+	else
+	{
+	  any_display = TRUE;
+	  gdk_draw_string (box->pixmap, da->style->font, 
+	      da->style->fg_gc[GTK_WIDGET_STATE (da)], 
+	      x, y + (face_display * 3), 
+	      m->subject);
+	  y += box->height;
 	}
       }
-      gdk_draw_string (box->pixmap, da->style->font, 
-	  da->style->fg_gc[GTK_WIDGET_STATE (da)], x, y + (face_display * 3), 
-	  m->from);
-      y += box->height;
-      gdk_draw_string (box->pixmap, da->style->font, 
-	  da->style->fg_gc[GTK_WIDGET_STATE (da)], x, y + (face_display * 3), 
-	  m->subject);
-      y += box->height;
       if (face_display)
 	y += box->height;
-      gdk_draw_line (box->pixmap, da->style->dark_gc[GTK_WIDGET_STATE (da)],
-/*	  (2 + (50 * !face_display)), y - box->height + 3,  */
-	  x, y - box->height + 3,  
-	  da->allocation.width - 18, 
-	  y - box->height + 3);
+      if (face_display || any_display)
+      {
+	gdk_draw_line (box->pixmap, da->style->dark_gc[GTK_WIDGET_STATE (da)],
+	    /*	  (2 + (50 * !face_display)), y - box->height + 3,  */
+	    x, y - box->height + 3,  
+	    da->allocation.width - 18, 
+	    y - box->height + 3);
+      }
     }
     headers = headers->next;
   }
@@ -314,6 +341,9 @@ void gbuffy_display_box (BOX_INFO *box, int xpos, int ypos)
   int height = 16, width = 0;
   int x, num = 0;
   int change;
+  int screen_height;
+
+  screen_height = gdk_screen_height();
 
   if (box->w == NULL)
   {
@@ -358,6 +388,10 @@ void gbuffy_display_box (BOX_INFO *box, int xpos, int ypos)
 	      width = x;
 	    num++;
 	  }
+	  if (!(m->subject))
+	  {
+	    m->subject = safe_strdup(NO_SUBJECT_STRING);
+	  }
 	  if (m->subject)
 	  {
 	    x = gdk_string_measure (box->w->style->font, m->subject);
@@ -381,6 +415,17 @@ void gbuffy_display_box (BOX_INFO *box, int xpos, int ypos)
     }
     box->height = height;
     da = gtk_drawing_area_new (); 
+    box->display_num = num;
+    box->skip_num = 0;
+    if (height * num > screen_height)
+    {
+      num = (screen_height / height) - 3;
+    }
+    if (num != box->display_num)
+    {
+      box->skip_num = box->display_num - num;
+      box->display_num = num;
+    }
     gtk_drawing_area_size (GTK_DRAWING_AREA (da), (box->face * 50) + width + 20,
 	(height) * num + 4);
     gtk_signal_connect (GTK_OBJECT (da), "expose_event",
@@ -490,6 +535,7 @@ gint gbuffy_poll_boxes (gpointer data)
   int change;
   gint cur_width;
   gint cur_height;
+  static unsigned int beenhere = 0;
 
   mbox = MailboxInfo;
   while (mbox != NULL)
@@ -523,7 +569,10 @@ gint gbuffy_poll_boxes (gpointer data)
   HorizPos.sign = POSITIVE;
   VertPos.sign = POSITIVE;
 
-  gdk_window_get_position (MainWindow->window, &HorizPos.value, &VertPos.value);
+  if (beenhere)
+    gdk_window_get_position (MainWindow->window, &HorizPos.value, &VertPos.value);
+  else
+    beenhere = 1;
 
   return TRUE;
 }
@@ -705,7 +754,7 @@ void parse_geometry(int *argc, char ***argv)
 {
   gint i, remove=0;
   gchar *p;
-  
+
   HorizPos.value=-1;
   HorizPos.sign=0;
   VertPos.value=-1;
@@ -714,29 +763,36 @@ void parse_geometry(int *argc, char ***argv)
   ScrH = gdk_screen_height();
   ScrW = gdk_screen_width();
 
-    for (i=0;i<*argc;i++) {
-      if(strcmp("--geometry", (*argv)[i]) == 0 ||
-	 strncmp("--geometry", (*argv)[i], 10) == 0 ||
-	 strcmp("-geometry", (*argv)[i]) == 0 ||
-	 strncmp("-geometry", (*argv)[i], 9) == 0) {
-	if((i+1) == *argc) {/* '-(-)geometry' was the _last_ argument */
-	  (*argv)[i] = NULL;
-	  remove = -1;
-	  break;
-	}
-	p = (*argv)[i+1];
-	while(*p) {
-	  switch(*p) {
+  for (i=0; i<*argc; i++) 
+  {
+    if (strcmp("--geometry", (*argv)[i]) == 0 ||
+	strncmp("--geometry", (*argv)[i], 10) == 0 ||
+	strcmp("-geometry", (*argv)[i]) == 0 ||
+	strncmp("-geometry", (*argv)[i], 9) == 0) 
+    {
+      if((i+1) == *argc) 
+      {  /* '-(-)geometry' was the _last_ argument */
+	(*argv)[i] = NULL;
+	remove = -1;
+	break;
+      }
+      p = (*argv)[i+1];
+      while(*p) 
+      {
+	switch(*p) 
+	{
 	  case 'x': 
 	    Height = strtol(p + 1, &p, 10);
 	    break;
 	  case '-':
 	  case '+':
-	    if (HorizPos.value == -1) {
+	    if (HorizPos.value == -1) 
+	    {
 	      HorizPos.sign = (*p == '-') ? NEGATIVE : POSITIVE;
 	      HorizPos.value = strtol(p+1, &p, 10);
 	    }
-	    else {
+	    else 
+	    {
 	      VertPos.sign = (*p == '-') ? NEGATIVE : POSITIVE;
 	      VertPos.value = strtol(p+1, &p, 10);
 	    }
@@ -744,23 +800,29 @@ void parse_geometry(int *argc, char ***argv)
 	  default:
 	    Width = strtol(p, &p, 10);
 	    break;
-	  }
-	}	    /* while(p) */
-	(*argv)[i] = NULL;
-	(*argv)[i+1] = NULL;
-	break; /* We are done here */
+	}
+      }	    /* while(p) */
+      (*argv)[i] = NULL;
+      (*argv)[i+1] = NULL;
+      break; /* We are done here */
+    }
+  }
+  if (remove == -1) 
+  {
+    argc--;
+  }
+  else 
+  {
+    for(i=1;i<*argc;i++) 
+    { /* Remove NULL:ed argv entries */
+      if ((*argv)[i] == NULL) 
+      {
+	(*argv)[i] = (*argv)[i+2];
+	remove++;
       }
     }
-    if (remove == -1) 
-      argc--;
-    else 
-      for(i=1;i<*argc;i++) { /* Remove NULL:ed argv entries */
-	if ((*argv)[i] == NULL) {
-	  (*argv)[i] = (*argv)[i+2];
-	  remove++;
-	}
-      }
-    *argc-=remove;
+  }
+  *argc-=remove;
 }        
 
 int main (int argc, char *argv[])
@@ -790,7 +852,7 @@ int main (int argc, char *argv[])
     if (!Homedir)
       Homedir = safe_strdup (pw->pw_dir);
   }
-  parse_geometry(&argc, &argv);
+  parse_geometry(&argc, &argv); 
   
 #ifdef DEBUG
   if (argc == 3) 
@@ -806,12 +868,13 @@ int main (int argc, char *argv[])
 	g_print ("-E- Unable to open debugfile %s\n", path);
 	gtk_exit (-1);
       }
+      setvbuf(debugfile,NULL,_IONBF,0);
       g_print ("-I- Debugging at level %d\n", debuglevel);
     }
   }
   g_print("Will set:\nWidth: %d\nHeight: %d\nXOFF: %d:%d\nYOFF: %d:%d\n",
-	  width, height, horizontal.sign, horizontal.value, vertical.sign, 
-	  vertical.value);
+	  Width, Height, HorizPos.sign, HorizPos.value, VertPos.sign, 
+	  VertPos.value);
 #endif
 
 
@@ -828,7 +891,7 @@ int main (int argc, char *argv[])
       MailboxInfo->path = safe_strdup (path);
     }
     MailboxInfo->title = safe_strdup ("Spool");
-    MailboxInfo->command = safe_strdup ("mutt");
+    MailboxInfo->command = safe_strdup ("xterm -e sh -c 'echo Sorry, no command configured.  Press enter.; read'");
   }
 
   gbuffy_display ();
