@@ -119,6 +119,8 @@ int password_prompt_dialog (char *prompt, char *user, size_t userlen,
   
   pd.dialog = gtk_dialog_new ();
   pd.ok = 0;
+  pd.user = NULL;
+  pd.pass = NULL;
   destroy_sig = gtk_signal_connect (GTK_OBJECT (pd.dialog), "destroy", 
 		      (GtkSignalFunc) quit_dialog, &pd.dialog);
 
@@ -173,8 +175,14 @@ int password_prompt_dialog (char *prompt, char *user, size_t userlen,
   gtk_widget_show (pd.dialog);
   gtk_main ();
   gtk_signal_disconnect (GTK_OBJECT (pd.dialog), destroy_sig);
-  strfcpy (user, pd.user, userlen);
-  strfcpy (pass, pd.pass, passlen);
+  if (pd.user)
+  {
+    strfcpy (user, pd.user, userlen);
+  }
+  if (pd.pass)
+  {
+    strfcpy (pass, pd.pass, passlen);
+  }
   gtk_widget_destroy (pd.dialog);
   return pd.ok;
 }
