@@ -418,6 +418,7 @@ static int parse_fetch (BOX_INFO *ibox, CONNECTION *conn, GList *headers,
 	m->from = safe_strdup (from);
 	m->subject = safe_strdup (subject);
 	m->face = safe_strdup (xface);
+	*from = *subject = *xface = '\0';
 	headers = g_list_append (headers, m);
       }
     }
@@ -432,7 +433,7 @@ static int imap_fetch_new_headers (BOX_INFO *ibox, CONNECTION *conn, GList *head
   char buf[LONG_STRING];
   char seq[8];
   char *s;
-  int unseen = 0;
+  int unseen = 1;
 
   /* Open mailbox (EXAMINE) and find the first UNSEEN message */
   imap_make_sequence (seq, sizeof (seq));
@@ -512,6 +513,9 @@ int imap_folder_count (BOX_INFO *ibox, int force, GList *headers)
 
   if (conn->uses == 0)
   {
+    /* a bit hackish I guess */
+    conn->ssl_mode = ibox->ssl_mode;
+
     if (imap_open_connection (ibox, conn) < 0)
       return (-1);
     /* For this application, this is only an "in use" variable */
@@ -544,7 +548,10 @@ int imap_folder_count (BOX_INFO *ibox, int force, GList *headers)
       if (strncasecmp ("STATUS", s, 6) == 0)
       {
 	s = imap_next_word (s);
-	if (strncmp (ibox->path, s, strlen (ibox->path)) == 0)
+	if ((strncmp (ibox->path, s, strlen (ibox->path)) == 0) ||
+            (s[0] == '"' && 
+             (!strncmp(ibox->path,s+1,strlen(ibox->path))) &&
+             s[1+strlen(ibox->path)] == '"'))
 	{
 	  s = imap_next_word (s);
 	  if (*s == '(')
